// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `QUDT VOCAB Quantity Kinds  Release 2.1.12` vocabulary
//!
//! This module requires `ns-quantitykind` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**|QUDT VOCAB Quantity Kinds  Release 2.1.12|
//! |**Prefix**|quantitykind|
//! |**Namespace base IRI**|<http://qudt.org/vocab/quantitykind/>|
//! |**Description**||
//! |**Is defined by**|<http://qudt.org/vocab/quantitykind/>|
//!

use crate::namespace;

namespace!(
    "http://qudt.org/vocab/quantitykind/",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Absolute Activity`: 
    AbsoluteActivity, "AbsoluteActivity",
    /// `Absolute Humidity`: 
    AbsoluteHumidity, "AbsoluteHumidity",
    /// `Absorbed Dose`: Note that the absorbed dose is not a good indicator of the likely biological effect. 1 Gy of alpha radiation would be much more biologically damaging than 1 Gy of photon radiation for example. Appropriate weighting factors can be applied reflecting the different relative biological effects to find the equivalent dose. The risk of stoctic effects due to radiation exposure can be quantified using the effective dose, which is a weighted average of the equivalent dose to each organ depending upon its radiosensitivity. When ionising radiation is used to treat cancer, the doctor will usually prescribe the radiotherapy treatment in Gy. When risk from ionising radiation is being discussed, a related unit, the Sievert is used.
    AbsorbedDose, "AbsorbedDose",
    /// `Absorbed Dose Rate`: 
    AbsorbedDoseRate, "AbsorbedDoseRate",
    /// `Absorptance`: 
    Absorptance, "Absorptance",
    /// `Acceleration`: 
    Acceleration, "Acceleration",
    /// `Acceleration Of Gravity`: 
    AccelerationOfGravity, "AccelerationOfGravity",
    /// `Acceptor Density`: 
    AcceptorDensity, "AcceptorDensity",
    /// `Acceptor Ionization Energy`: 
    AcceptorIonizationEnergy, "AcceptorIonizationEnergy",
    /// `Acoustic Impediance`: 
    AcousticImpedance, "AcousticImpedance",
    /// `Action`: 
    Action, "Action",
    /// `Action Time`: Action Time (sec) 
    ActionTime, "ActionTime",
    /// `Active Energy`: 
    ActiveEnergy, "ActiveEnergy",
    /// `Active Power`: 
    ActivePower, "ActivePower",
    /// `Activity`: 
    Activity, "Activity",
    /// `Activity Coefficient`: 
    ActivityCoefficient, "ActivityCoefficient",
    /// `Activity Concentration`: 
    ActivityConcentration, "ActivityConcentration",
    /// `Activity Thresholds`: 
    ActivityThresholds, "ActivityThresholds",
    /// `Adaptation`: 
    Adaptation, "Adaptation",
    /// `Admittance`: 
    Admittance, "Admittance",
    /// `Alpha Disintegration Energy`: 
    AlphaDisintegrationEnergy, "AlphaDisintegrationEnergy",
    /// `Altitude`: 
    Altitude, "Altitude",
    /// `Ambient Pressure`: 
    AmbientPressure, "AmbientPressure",
    /// `Amount of Substance`: 
    AmountOfSubstance, "AmountOfSubstance",
    /// `Amount of Substance of Concentration of B`: 
    AmountOfSubstanceConcentrationOfB, "AmountOfSubstanceConcentrationOfB",
    /// `Amount of Substance of Fraction of B`: 
    AmountOfSubstanceFractionOfB, "AmountOfSubstanceFractionOfB",
    /// `Amount of Substance per Unit Mass`: 
    AmountOfSubstancePerUnitMass, "AmountOfSubstancePerUnitMass",
    /// `Molar Mass variation due to Pressure`: 
    AmountOfSubstancePerUnitMassPressure, "AmountOfSubstancePerUnitMassPressure",
    /// `Amount of Substance per Unit Volume`: 
    AmountOfSubstancePerUnitVolume, "AmountOfSubstancePerUnitVolume",
    /// `Angle`: 
    Angle, "Angle",
    /// `Angle Of Attack`: 
    AngleOfAttack, "AngleOfAttack",
    /// `Angle of Optical Rotation`: 
    AngleOfOpticalRotation, "AngleOfOpticalRotation",
    /// `Angular Acceleration`: 
    AngularAcceleration, "AngularAcceleration",
    /// `Angular Cross-section`: 
    AngularCrossSection, "AngularCrossSection",
    /// `Angular Distance`: 
    AngularDistance, "AngularDistance",
    /// `Angular Frequency`: 
    AngularFrequency, "AngularFrequency",
    /// `Angular Impulse`: 
    AngularImpulse, "AngularImpulse",
    /// `Angular Momentum`: 
    AngularMomentum, "AngularMomentum",
    /// `Angular Reciprocal Lattice Vector`: 
    AngularReciprocalLatticeVector, "AngularReciprocalLatticeVector",
    /// `Angular Velocity`: 
    AngularVelocity, "AngularVelocity",
    /// `Angular Wavenumber`: 
    AngularWavenumber, "AngularWavenumber",
    /// `Apogee Radius`: 
    ApogeeRadius, "ApogeeRadius",
    /// `Apparent Power`: 
    ApparentPower, "ApparentPower",
    /// `Area`: 
    Area, "Area",
    /// `Area Angle`: 
    AreaAngle, "AreaAngle",
    /// `Area per Time`: 
    AreaPerTime, "AreaPerTime",
    /// `Area Ratio`: 
    AreaRatio, "AreaRatio",
    /// `Area Temperature`: 
    AreaTemperature, "AreaTemperature",
    /// `Area Thermal Expansion`: 
    AreaThermalExpansion, "AreaThermalExpansion",
    /// `Area Time`: 
    AreaTime, "AreaTime",
    /// `Area Time Temperature`: 
    AreaTimeTemperature, "AreaTimeTemperature",
    /// `Aeric Heat Flow Rate`: 
    AreicHeatFlowRate, "AreicHeatFlowRate",
    /// `Asset`: 
    Asset, "Asset",
    /// `Atmospheric Pressure`: 
    AtmosphericPressure, "AtmosphericPressure",
    /// `Atom Scattering Factor`: 
    AtomScatteringFactor, "AtomScatteringFactor",
    /// `Atomic Attenuation Coefficient`: 
    AtomicAttenuationCoefficient, "AtomicAttenuationCoefficient",
    /// `Atomic Charge`: 
    AtomicCharge, "AtomicCharge",
    /// `Atomic Mass`: 
    AtomicMass, "AtomicMass",
    /// `Atomic Number`: 
    AtomicNumber, "AtomicNumber",
    /// `AtomicUnitOfCharge`: 
    AtomicUnitOfCharge, "AtomicUnitOfCharge",
    /// `Attenuation Coefficient`: 
    AttenuationCoefficient, "AttenuationCoefficient",
    /// `Auditory Thresholds`: 
    AuditoryThresholds, "AuditoryThresholds",
    /// `Auxillary Magnetic Field`: 
    AuxillaryMagneticField, "AuxillaryMagneticField",
    /// `Average Energy Loss per Elementary Charge Produced`: 
    AverageEnergyLossPerElementaryChargeProduced, "AverageEnergyLossPerElementaryChargeProduced",
    /// `Average Head End Pressure`: 
    AverageHeadEndPressure, "AverageHeadEndPressure",
    /// `Average Logarithmic Energy Decrement`: 
    AverageLogarithmicEnergyDecrement, "AverageLogarithmicEnergyDecrement",
    /// `Average Specific Impulse`: Avg Specific Impulse (lbf-sec/lbm) 
    AverageSpecificImpulse, "AverageSpecificImpulse",
    /// `Average Vacuum Thrust`: 
    AverageVacuumThrust, "AverageVacuumThrust",
    /// `Bending Moment of Force`: 
    BendingMomentOfForce, "BendingMomentOfForce",
    /// `Beta Disintegration Energy`: 
    BetaDisintegrationEnergy, "BetaDisintegrationEnergy",
    /// `Bevel Gear Pitch Angle`: 
    BevelGearPitchAngle, "BevelGearPitchAngle",
    /// `Binding Fraction`: 
    BindingFraction, "BindingFraction",
    /// `Blood Glucose Level`: citation: https://en.wikipedia.org/wiki/Blood_sugar_level
    BloodGlucoseLevel, "BloodGlucoseLevel",
    /// `Blood Glucose Level by Mass`: citation: https://en.wikipedia.org/wiki/Blood_sugar_level
    BloodGlucoseLevel_Mass, "BloodGlucoseLevel_Mass",
    /// `Body Mass Index`: 
    BodyMassIndex, "BodyMassIndex",
    /// `Bragg Angle`: 
    BraggAngle, "BraggAngle",
    /// `Breadth`: 
    Breadth, "Breadth",
    /// `Buckling Factor`: 
    BucklingFactor, "BucklingFactor",
    /// `Bulk Modulus`: 
    BulkModulus, "BulkModulus",
    /// `Burgers Vector`: 
    BurgersVector, "BurgersVector",
    /// `Burn Rate`: 
    BurnRate, "BurnRate",
    /// `Burn Time`: 
    BurnTime, "BurnTime",
    /// `Center of Gravity in the X axis`: 
    CENTER_OF_GRAVITY_X, "CENTER-OF-GRAVITY_X",
    /// `Center of Gravity in the Y axis`: 
    CENTER_OF_GRAVITY_Y, "CENTER-OF-GRAVITY_Y",
    /// `Center of Gravity in the X axis`: 
    CENTER_OF_GRAVITY_Z, "CENTER-OF-GRAVITY_Z",
    /// `Center of Mass (CoM)`: 
    CENTER_OF_MASS, "CENTER-OF-MASS",
    /// `Contract End Item (CEI) Specification Mass.`: 
    CONTRACT_END_ITEM_SPECIFICATION_MASS, "CONTRACT-END-ITEM-SPECIFICATION-MASS",
    /// `Control Mass.`: 
    CONTROL_MASS, "CONTROL-MASS",
    /// `Canonical Partition Function`: 
    CanonicalPartitionFunction, "CanonicalPartitionFunction",
    /// `Capacitance`: 
    Capacitance, "Capacitance",
    /// `Capacity`: 
    Capacity, "Capacity",
    /// `Carrier LifetIme`: 
    CarrierLifetime, "CarrierLifetime",
    /// `Cartesian Area`: 
    CartesianArea, "CartesianArea",
    /// `Cartesian Coordinates`: 
    CartesianCoordinates, "CartesianCoordinates",
    /// `Volume`: 
    CartesianVolume, "CartesianVolume",
    /// `Catalytic Activity`: 
    CatalyticActivity, "CatalyticActivity",
    /// `Celsius temperature`: 
    CelsiusTemperature, "CelsiusTemperature",
    /// `Characteristic Acoustic Impedance`: 
    CharacteristicAcousticImpedance, "CharacteristicAcousticImpedance",
    /// `Characteristic Velocity`: 
    CharacteristicVelocity, "CharacteristicVelocity",
    /// `Charge Number`: 
    ChargeNumber, "ChargeNumber",
    /// `Chemical Affinity`: 
    ChemicalAffinity, "ChemicalAffinity",
    /// `Chemical Potential`: 
    ChemicalPotential, "ChemicalPotential",
    /// `Circulation`: 
    Circulation, "Circulation",
    /// `Closest Approach Radius`: 
    ClosestApproachRadius, "ClosestApproachRadius",
    /// `Coefficient of heat transfer`: 
    CoefficientOfHeatTransfer, "CoefficientOfHeatTransfer",
    /// `Coercivity`: 
    Coercivity, "Coercivity",
    /// `Coherence Length`: 
    CoherenceLength, "CoherenceLength",
    /// `Cold Receptor Threshold`: 
    ColdReceptorThreshold, "ColdReceptorThreshold",
    /// `Combined Non Evaporative Heat Transfer Coefficient`: 
    CombinedNonEvaporativeHeatTransferCoefficient, "CombinedNonEvaporativeHeatTransferCoefficient",
    /// `Combustion Chamber Temperature`: 
    CombustionChamberTemperature, "CombustionChamberTemperature",
    /// `Complex Power`: 
    ComplexPower, "ComplexPower",
    /// `Compressibility`: 
    Compressibility, "Compressibility",
    /// `Compressibility Factor`: 
    CompressibilityFactor, "CompressibilityFactor",
    /// `Concentration`: 
    Concentration, "Concentration",
    /// `Conductance`: 
    Conductance, "Conductance",
    /// `Conduction Speed`: 
    ConductionSpeed, "ConductionSpeed",
    /// `Conductive Heat Transfer Rate`: 
    ConductiveHeatTransferRate, "ConductiveHeatTransferRate",
    /// `Conductivity`: 
    Conductivity, "Conductivity",
    /// `Convective Heat Transfer`: 
    ConvectiveHeatTransfer, "ConvectiveHeatTransfer",
    /// `Coupling Factor`: 
    CouplingFactor, "CouplingFactor",
    /// `Cross-section`: 
    CrossSection, "CrossSection",
    /// `Cross-sectional Area`: 
    CrossSectionalArea, "CrossSectionalArea",
    /// `Cubic Electric Dipole Moment per Square Energy`: 
    CubicElectricDipoleMomentPerSquareEnergy, "CubicElectricDipoleMomentPerSquareEnergy",
    /// `Cubic Expansion Coefficient`: 
    CubicExpansionCoefficient, "CubicExpansionCoefficient",
    /// `Curie Temperature`: 
    CurieTemperature, "CurieTemperature",
    /// `Currency`: 
    Currency, "Currency",
    /// `Current Linkage`: 
    CurrentLinkage, "CurrentLinkage",
    /// `Curvature`: 
    Curvature, "Curvature",
    /// `Curvature`: 
    CurvatureFromRadius, "CurvatureFromRadius",
    /// `Larmor Angular Frequency`: 
    CyclotronAngularFrequency, "CyclotronAngularFrequency",
    /// `Delta-V`: 
    DELTA_V, "DELTA-V",
    /// `Dry Mass`: 
    DRY_MASS, "DRY-MASS",
    /// `Data Rate`: 
    DataRate, "DataRate",
    /// `Debye-Waller Factor`: 
    Debye_WallerFactor, "Debye-WallerFactor",
    /// `Debye Angular Frequency`: 
    DebyeAngularFrequency, "DebyeAngularFrequency",
    /// `Debye Angular Wavenumber`: 
    DebyeAngularWavenumber, "DebyeAngularWavenumber",
    /// `Debye Temperature`: 
    DebyeTemperature, "DebyeTemperature",
    /// `Decay Constant`: 
    DecayConstant, "DecayConstant",
    /// `Degree of Dissociation`: 
    DegreeOfDissociation, "DegreeOfDissociation",
    /// `Density`: 
    Density, "Density",
    /// `Density In Combustion Chamber`: 
    DensityInCombustionChamber, "DensityInCombustionChamber",
    /// `Density of states`: 
    DensityOfStates, "DensityOfStates",
    /// `Density Of The Exhaust Gases`: 
    DensityOfTheExhaustGases, "DensityOfTheExhaustGases",
    /// `Depth`: 
    Depth, "Depth",
    /// `Dew Point Temperature`: 
    DewPointTemperature, "DewPointTemperature",
    /// `Diameter`: 
    Diameter, "Diameter",
    /// `Diastolic Blood Pressure`: 
    DiastolicBloodPressure, "DiastolicBloodPressure",
    /// `Diffusion Area`: 
    DiffusionArea, "DiffusionArea",
    /// `Diffusion Coefficient`: 
    DiffusionCoefficient, "DiffusionCoefficient",
    /// `Diffusion Coefficient for Fluence Rate`: 
    DiffusionCoefficientForFluenceRate, "DiffusionCoefficientForFluenceRate",
    /// `Diffusion Length`: 
    DiffusionLength, "DiffusionLength",
    /// `Dimensionless`: 
    Dimensionless, "Dimensionless",
    /// `Dimensionless Ratio`: 
    DimensionlessRatio, "DimensionlessRatio",
    /// `Displacement`: 
    Displacement, "Displacement",
    /// `Displacement Current`: 
    DisplacementCurrent, "DisplacementCurrent",
    /// `Displacement Current Density`: 
    DisplacementCurrentDensity, "DisplacementCurrentDensity",
    /// `Displacement Vector of Ion`: 
    DisplacementVectorOfIon, "DisplacementVectorOfIon",
    /// `Dissipance`: 
    Dissipance, "Dissipance",
    /// `Distance`: 
    Distance, "Distance",
    /// `Distance Traveled During a Burn`: 
    DistanceTraveledDuringBurn, "DistanceTraveledDuringBurn",
    /// `Donor Density`: 
    DonorDensity, "DonorDensity",
    /// `Donor Ionization Energy`: 
    DonorIonizationEnergy, "DonorIonizationEnergy",
    /// `Dose Equivalent`: 
    DoseEquivalent, "DoseEquivalent",
    /// `Dose Equivalent Quality Factor`: 
    DoseEquivalentQualityFactor, "DoseEquivalentQualityFactor",
    /// `Drag Coefficient`: 
    DragCoefficient, "DragCoefficient",
    /// `Drag Force`: 
    DragForce, "DragForce",
    /// `Dry Volume`: 
    DryVolume, "DryVolume",
    /// `Dynamic Friction`: 
    DynamicFriction, "DynamicFriction",
    /// `Dynamic Friction Coefficient`: 
    DynamicFrictionCoefficient, "DynamicFrictionCoefficient",
    /// `Dynamic Pressure`: 
    DynamicPressure, "DynamicPressure",
    /// `Dynamic Viscosity`: 
    DynamicViscosity, "DynamicViscosity",
    /// `Earth Closest Approach Vehicle Velocity`: 
    EarthClosestApproachVehicleVelocity, "EarthClosestApproachVehicleVelocity",
    /// `Eccentricity Of Orbit`: 
    EccentricityOfOrbit, "EccentricityOfOrbit",
    /// `Effective Exhaustvelocity`: 
    EffectiveExhaustVelocity, "EffectiveExhaustVelocity",
    /// `Effective Mass`: 
    EffectiveMass, "EffectiveMass",
    /// `Effective Multiplication Factor`: 
    EffectiveMultiplicationFactor, "EffectiveMultiplicationFactor",
    /// `Efficiency`: 
    Efficiency, "Efficiency",
    /// `Einstein Transition Probability`: 
    EinsteinTransitionProbability, "EinsteinTransitionProbability",
    /// `Electric Charge`: 
    ElectricCharge, "ElectricCharge",
    /// `Electric Charge Density`: 
    ElectricChargeDensity, "ElectricChargeDensity",
    /// `Electric Charge Line Density`: 
    ElectricChargeLineDensity, "ElectricChargeLineDensity",
    /// `Electric Charge Linear Density`: 
    ElectricChargeLinearDensity, "ElectricChargeLinearDensity",
    /// `Electric charge per amount of substance`: 
    ElectricChargePerAmountOfSubstance, "ElectricChargePerAmountOfSubstance",
    /// `Electric charge per area`: 
    ElectricChargePerArea, "ElectricChargePerArea",
    /// `Electric Charge Per Mass`: 
    ElectricChargePerMass, "ElectricChargePerMass",
    /// `Electric Charge Surface Density`: 
    ElectricChargeSurfaceDensity, "ElectricChargeSurfaceDensity",
    /// `Electric Charge Volume Density`: 
    ElectricChargeVolumeDensity, "ElectricChargeVolumeDensity",
    /// `Electric Conductivity`: 
    ElectricConductivity, "ElectricConductivity",
    /// `Electric Current`: 
    ElectricCurrent, "ElectricCurrent",
    /// `Electric Current Density`: 
    ElectricCurrentDensity, "ElectricCurrentDensity",
    /// `Electric Current per Angle`: 
    ElectricCurrentPerAngle, "ElectricCurrentPerAngle",
    /// `Electric Current per Unit Energy`: 
    ElectricCurrentPerUnitEnergy, "ElectricCurrentPerUnitEnergy",
    /// `Electric Current per Unit Length`: 
    ElectricCurrentPerUnitLength, "ElectricCurrentPerUnitLength",
    /// `Electric Current per Unit Temperature`: 
    ElectricCurrentPerUnitTemperature, "ElectricCurrentPerUnitTemperature",
    /// `Electric Current Phasor`: 
    ElectricCurrentPhasor, "ElectricCurrentPhasor",
    /// `Electric Dipole Moment`: 
    ElectricDipoleMoment, "ElectricDipoleMoment",
    /// `Electric Displacement`: 
    ElectricDisplacement, "ElectricDisplacement",
    /// `Electric Displacement Field`: 
    ElectricDisplacementField, "ElectricDisplacementField",
    /// `Electric Field`: 
    ElectricField, "ElectricField",
    /// `Electric Field Strength`: 
    ElectricFieldStrength, "ElectricFieldStrength",
    /// `Electric Flux`: 
    ElectricFlux, "ElectricFlux",
    /// `Electric Flux Density`: 
    ElectricFluxDensity, "ElectricFluxDensity",
    /// `Electric Polarizability`: 
    ElectricPolarizability, "ElectricPolarizability",
    /// `Electric Polarization`: 
    ElectricPolarization, "ElectricPolarization",
    /// `Electric Potential`: 
    ElectricPotential, "ElectricPotential",
    /// `Electric Potential Difference`: 
    ElectricPotentialDifference, "ElectricPotentialDifference",
    /// `Electric Power`: 
    ElectricPower, "ElectricPower",
    /// `Electric Propulsion Propellant Mass`: 
    ElectricPropulsionPropellantMass, "ElectricPropulsionPropellantMass",
    /// `Electric Quadrupole Moment`: 
    ElectricQuadrupoleMoment, "ElectricQuadrupoleMoment",
    /// `Electric Susceptibility`: 
    ElectricSusceptibility, "ElectricSusceptibility",
    /// `Electrical Power To Mass Ratio`: 
    ElectricalPowerToMassRatio, "ElectricalPowerToMassRatio",
    /// `Electrolytic Conductivity`: 
    ElectrolyticConductivity, "ElectrolyticConductivity",
    /// `Electromagnetic Energy Density`: 
    ElectromagneticEnergyDensity, "ElectromagneticEnergyDensity",
    /// `Permeability`: 
    ElectromagneticPermeability, "ElectromagneticPermeability",
    /// `Electromagnetic Permeability Ratio`: 
    ElectromagneticPermeabilityRatio, "ElectromagneticPermeabilityRatio",
    /// `Electromagnetic Wave Phase Speed`: 
    ElectromagneticWavePhaseSpeed, "ElectromagneticWavePhaseSpeed",
    /// `Electromotive Force`: 
    ElectromotiveForce, "ElectromotiveForce",
    /// `Electron Affinity`: 
    ElectronAffinity, "ElectronAffinity",
    /// `Electron Density`: 
    ElectronDensity, "ElectronDensity",
    /// `Electron Mean Free Path`: 
    ElectronMeanFreePath, "ElectronMeanFreePath",
    /// `Electron Radius`: 
    ElectronRadius, "ElectronRadius",
    /// `Elementary Charge`: 
    ElementaryCharge, "ElementaryCharge",
    /// `Elliptical Orbit Apogee Velocity`: 
    EllipticalOrbitApogeeVelocity, "EllipticalOrbitApogeeVelocity",
    /// `Elliptical Orbit Perigee Velocity`: 
    EllipticalOrbitPerigeeVelocity, "EllipticalOrbitPerigeeVelocity",
    /// `Emissivity`: 
    Emissivity, "Emissivity",
    /// `Energy`: 
    Energy, "Energy",
    /// `Energy Density`: 
    EnergyDensity, "EnergyDensity",
    /// `Energy Density of States`: 
    EnergyDensityOfStates, "EnergyDensityOfStates",
    /// `Energy Expenditure`: 
    EnergyExpenditure, "EnergyExpenditure",
    /// `Energy Fluence`: 
    EnergyFluence, "EnergyFluence",
    /// `Energy Fluence Rate`: 
    EnergyFluenceRate, "EnergyFluenceRate",
    /// `Energy Imparted`: 
    EnergyImparted, "EnergyImparted",
    /// `Internal Energy`: 
    EnergyInternal, "EnergyInternal",
    /// `Kinetic Energy`: 
    EnergyKinetic, "EnergyKinetic",
    /// `Energy Level`: 
    EnergyLevel, "EnergyLevel",
    /// `Energy per Area`: 
    EnergyPerArea, "EnergyPerArea",
    /// `Energy Per Area Electric Charge`: 
    EnergyPerAreaElectricCharge, "EnergyPerAreaElectricCharge",
    /// `Energy per electric charge`: 
    EnergyPerElectricCharge, "EnergyPerElectricCharge",
    /// `Energy and work per mass amount of substance`: 
    EnergyPerMassAmountOfSubstance, "EnergyPerMassAmountOfSubstance",
    /// `Energy Per Square Magnetic Flux Density`: 
    EnergyPerSquareMagneticFluxDensity, "EnergyPerSquareMagneticFluxDensity",
    /// `Energy per temperature`: 
    EnergyPerTemperature, "EnergyPerTemperature",
    /// `Enthalpy`: 
    Enthalpy, "Enthalpy",
    /// `Entropy`: 
    Entropy, "Entropy",
    /// `Equilibrium Constant`: 
    EquilibriumConstant, "EquilibriumConstant",
    /// `Equilibrium Constant on Concentration Basis`: The unit is unit:MOL-PER-M3 raised to the N where N is the summation of stoichiometric numbers. I don't know what to do with this.
    EquilibriumConstantOnConcentrationBasis, "EquilibriumConstantOnConcentrationBasis",
    /// `Equilibrium Constant on Pressure Basis`: 
    EquilibriumConstantOnPressureBasis, "EquilibriumConstantOnPressureBasis",
    /// `Equilibrium Position Vector of Ion`: 
    EquilibriumPositionVectorOfIon, "EquilibriumPositionVectorOfIon",
    /// `Equivalent absorption area`: 
    EquivalentAbsorptionArea, "EquivalentAbsorptionArea",
    /// `Evaporative Heat Transfer`: 
    EvaporativeHeatTransfer, "EvaporativeHeatTransfer",
    /// `Combined Non Evaporative Heat Transfer Coefficient`: 
    EvaporativeHeatTransferCoefficient, "EvaporativeHeatTransferCoefficient",
    /// `Exchange Integral`: 
    ExchangeIntegral, "ExchangeIntegral",
    /// `Exhaust Gas Mean Molecular Weight`: 
    ExhaustGasMeanMolecularWeight, "ExhaustGasMeanMolecularWeight",
    /// `Exhaust Gases Specific Heat`: 
    ExhaustGasesSpecificHeat, "ExhaustGasesSpecificHeat",
    /// `Exhaust Stream Power`: 
    ExhaustStreamPower, "ExhaustStreamPower",
    /// `Exit Plane Cross-sectional Area`: 
    ExitPlaneCrossSectionalArea, "ExitPlaneCrossSectionalArea",
    /// `Exit Plane Pressure`: 
    ExitPlanePressure, "ExitPlanePressure",
    /// `Exit Plane Temperature`: 
    ExitPlaneTemperature, "ExitPlaneTemperature",
    /// `Expansion Ratio`: 
    ExpansionRatio, "ExpansionRatio",
    /// `Exposure`: 
    Exposure, "Exposure",
    /// `Exposure Rate`: 
    ExposureRate, "ExposureRate",
    /// `Extent of Reaction`: 
    ExtentOfReaction, "ExtentOfReaction",
    /// `Flight Performance Reserve Propellant Mass`: 
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS, "FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS",
    /// `Fuel Bias`: 
    FUEL_BIAS, "FUEL-BIAS",
    /// `Fast Fission Factor`: 
    FastFissionFactor, "FastFissionFactor",
    /// `Fermi Angular Wavenumber`: 
    FermiAngularWavenumber, "FermiAngularWavenumber",
    /// `Fermi Energy`: 
    FermiEnergy, "FermiEnergy",
    /// `Fermi Temperature`: 
    FermiTemperature, "FermiTemperature",
    /// `Final Or Current Vehicle Mass`: 
    FinalOrCurrentVehicleMass, "FinalOrCurrentVehicleMass",
    /// `First Moment of Area`: 
    FirstMomentOfArea, "FirstMomentOfArea",
    /// `First Stage Mass Ratio`: 
    FirstStageMassRatio, "FirstStageMassRatio",
    /// `Fission Core Radius To Height Ratio`: 
    FissionCoreRadiusToHeightRatio, "FissionCoreRadiusToHeightRatio",
    /// `Fission Fuel Utilization Factor`: 
    FissionFuelUtilizationFactor, "FissionFuelUtilizationFactor",
    /// `Fission Multiplication Factor`: 
    FissionMultiplicationFactor, "FissionMultiplicationFactor",
    /// `Flight Path Angle`: 
    FlightPathAngle, "FlightPathAngle",
    /// `Flux`: 
    Flux, "Flux",
    /// `Force`: 
    Force, "Force",
    /// `Force Magnitude`: 
    ForceMagnitude, "ForceMagnitude",
    /// `Force Per Area`: 
    ForcePerArea, "ForcePerArea",
    /// `Force Per Area Time`: 
    ForcePerAreaTime, "ForcePerAreaTime",
    /// `Force per Electric Charge`: 
    ForcePerElectricCharge, "ForcePerElectricCharge",
    /// `Force per Length`: 
    ForcePerLength, "ForcePerLength",
    /// `Fractional Mass (Stage 1)`: 
    FractionalMass_Stage1, "FractionalMass_Stage1",
    /// `Fractional Mass (Stage 2)`: 
    FractionalMass_Stage2, "FractionalMass_Stage2",
    /// `Fractional Mass (Stage 3)`: 
    FractionalMass_Stage3, "FractionalMass_Stage3",
    /// `Fractional Mass (Stages 1 through 3)`: 
    FractionallMass_Stages1_3, "FractionallMass_Stages1-3",
    /// `Frequency`: 
    Frequency, "Frequency",
    /// `Friction`: 
    Friction, "Friction",
    /// `Friction Coefficient`: 
    FrictionCoefficient, "FrictionCoefficient",
    /// `Fugacity`: 
    Fugacity, "Fugacity",
    /// `Fundamental Lattice vector`: 
    FundamentalLatticeVector, "FundamentalLatticeVector",
    /// `Fundamental Reciprocal Lattice Vector`: 
    FundamentalReciprocalLatticeVector, "FundamentalReciprocalLatticeVector",
    /// `g-Factor of Nucleus`: 
    GFactorOfNucleus, "GFactorOfNucleus",
    /// `Gross Lift-Off Weight`: 
    GROSS_LIFT_OFF_WEIGHT, "GROSS-LIFT-OFF-WEIGHT",
    /// `Gain`: 
    Gain, "Gain",
    /// `Gap Energy`: 
    GapEnergy, "GapEnergy",
    /// `Generalized Coordinate`: 
    GeneralizedCoordinate, "GeneralizedCoordinate",
    /// `Generalized Force`: 
    GeneralizedForce, "GeneralizedForce",
    /// `Generalized Force`: 
    GeneralizedMomentum, "GeneralizedMomentum",
    /// `Generalized Velocity`: 
    GeneralizedVelocity, "GeneralizedVelocity",
    /// `Gibbs Energy`: 
    GibbsEnergy, "GibbsEnergy",
    /// `Grand Canonical Partition Function`: 
    GrandCanonicalPartitionFunction, "GrandCanonicalPartitionFunction",
    /// `Gravitational Attraction`: 
    GravitationalAttraction, "GravitationalAttraction",
    /// `API Gravity`: 
    Gravity_API, "Gravity_API",
    /// `Group Speed of Sound`: 
    GroupSpeedOfSound, "GroupSpeedOfSound",
    /// `Gruneisen Parameter`: 
    GruneisenParameter, "GruneisenParameter",
    /// `Gustatory Threshold`: 
    GustatoryThreshold, "GustatoryThreshold",
    /// `Gyromagnetic Ratio`: 
    GyromagneticRatio, "GyromagneticRatio",
    /// `Half-life`: 
    Half_Life, "Half-Life",
    /// `Half-Value Thickness`: 
    Half_ValueThickness, "Half-ValueThickness",
    /// `Hall Coefficient`: 
    HallCoefficient, "HallCoefficient",
    /// `Hamilton Function`: 
    HamiltonFunction, "HamiltonFunction",
    /// `Head End Pressure`: 
    HeadEndPressure, "HeadEndPressure",
    /// `Heart Rate`: 
    HeartRate, "HeartRate",
    /// `Heat`: 
    Heat, "Heat",
    /// `Heat Capacity`: 
    HeatCapacity, "HeatCapacity",
    /// `Heat Capacity Ratio`: 
    HeatCapacityRatio, "HeatCapacityRatio",
    /// `Heat Flow Rate`: 
    HeatFlowRate, "HeatFlowRate",
    /// `Heat Flow Rate per Unit Area`: 
    HeatFlowRatePerUnitArea, "HeatFlowRatePerUnitArea",
    /// `Heat Flux Density`: 
    HeatFluxDensity, "HeatFluxDensity",
    /// `Height`: 
    Height, "Height",
    /// `Helmholtz Energy`: 
    HelmholtzEnergy, "HelmholtzEnergy",
    /// `Hole Density`: 
    HoleDensity, "HoleDensity",
    /// `Horizontal Velocity`: 
    HorizontalVelocity, "HorizontalVelocity",
    /// `Hyperfine Structure Quantum Number`: 
    HyperfineStructureQuantumNumber, "HyperfineStructureQuantumNumber",
    /// `Inert Mass`: 
    INERT_MASS, "INERT-MASS",
    /// `Ignition interval time`: 
    IgnitionIntervalTime, "IgnitionIntervalTime",
    /// `Illuminance`: 
    Illuminance, "Illuminance",
    /// `Impedance`: 
    Impedance, "Impedance",
    /// `Incidence`: 
    Incidence, "Incidence",
    /// `Incidence Proportion`: 
    IncidenceProportion, "IncidenceProportion",
    /// `Incidence Rate`: 
    IncidenceRate, "IncidenceRate",
    /// `Inductance`: 
    Inductance, "Inductance",
    /// `Infinite Multiplication Factor`: 
    InfiniteMultiplicationFactor, "InfiniteMultiplicationFactor",
    /// `Information Entropy`: 
    InformationEntropy, "InformationEntropy",
    /// `Information flow rate`: 
    InformationFlowRate, "InformationFlowRate",
    /// `Initial Expansion Ratio`: 
    InitialExpansionRatio, "InitialExpansionRatio",
    /// `Initial Nozzle Throat Diameter`: 
    InitialNozzleThroatDiameter, "InitialNozzleThroatDiameter",
    /// `Initial Vehicle Mass`: 
    InitialVehicleMass, "InitialVehicleMass",
    /// `Initial Velocity`: 
    InitialVelocity, "InitialVelocity",
    /// `Instantaneous Power`: 
    InstantaneousPower, "InstantaneousPower",
    /// `InternalConversionFactor`: 
    InternalConversionFactor, "InternalConversionFactor",
    /// `Internal Energy`: 
    InternalEnergy, "InternalEnergy",
    /// `Intinsic Carrier Density`: 
    IntinsicCarrierDensity, "IntinsicCarrierDensity",
    /// `Inverse amount of substance`: 
    InverseAmountOfSubstance, "InverseAmountOfSubstance",
    /// `Inverse Energy`: 
    InverseEnergy, "InverseEnergy",
    /// `Inverse Length`: 
    InverseLength, "InverseLength",
    /// `Inverse Length Temperature`: 
    InverseLengthTemperature, "InverseLengthTemperature",
    /// `Inverse Magnetic Flux`: 
    InverseMagneticFlux, "InverseMagneticFlux",
    /// `Inverse Permittivity`: 
    InversePermittivity, "InversePermittivity",
    /// `Inverse Pressure`: 
    InversePressure, "InversePressure",
    /// `Inverse Square Energy`: 
    InverseSquareEnergy, "InverseSquareEnergy",
    /// `Inverse Square Mass`: 
    InverseSquareMass, "InverseSquareMass",
    /// `Inverse Square Time`: 
    InverseSquareTime, "InverseSquareTime",
    /// `Inverse Temperature`: 
    InverseTemperature, "InverseTemperature",
    /// `Inverse Time`: 
    InverseTime, "InverseTime",
    /// `Inverse Time Temperature`: 
    InverseTimeTemperature, "InverseTimeTemperature",
    /// `Inverse Volume`: 
    InverseVolume, "InverseVolume",
    /// `Ion Current`: 
    IonCurrent, "IonCurrent",
    /// `Ion Density`: 
    IonDensity, "IonDensity",
    /// `Ion Transport Number`: 
    IonTransportNumber, "IonTransportNumber",
    /// `Ionic Charge`: 
    IonicCharge, "IonicCharge",
    /// `Ionic Strength`: 
    IonicStrength, "IonicStrength",
    /// `Ionization Energy`: 
    IonizationEnergy, "IonizationEnergy",
    /// `Irradiance`: 
    Irradiance, "Irradiance",
    /// `Isentropic Compressibility`: 
    IsentropicCompressibility, "IsentropicCompressibility",
    /// `Isentropic Exponent`: 
    IsentropicExponent, "IsentropicExponent",
    /// `Isothermal compressibility`: 
    IsothermalCompressibility, "IsothermalCompressibility",
    /// `Kerma`: 
    Kerma, "Kerma",
    /// `Kerma Rate`: 
    KermaRate, "KermaRate",
    /// `Kinematic Viscosity`: 
    KinematicViscosity, "KinematicViscosity",
    /// `Kinetic Energy`: 
    KineticEnergy, "KineticEnergy",
    /// `Lagrange Function`: 
    LagrangeFunction, "LagrangeFunction",
    /// `Landau-Ginzburg Number`: 
    Landau_GinzburgNumber, "Landau-GinzburgNumber",
    /// `Lande g-Factor`: 
    LandeGFactor, "LandeGFactor",
    /// `Larmor Angular Frequency`: 
    LarmorAngularFrequency, "LarmorAngularFrequency",
    /// `Lattice Plane Spacing`: 
    LatticePlaneSpacing, "LatticePlaneSpacing",
    /// `Lattice Vector`: 
    LatticeVector, "LatticeVector",
    /// `Leakage Factor`: 
    LeakageFactor, "LeakageFactor",
    /// `Length`: 
    Length, "Length",
    /// `Length Force`: 
    LengthByForce, "LengthByForce",
    /// `Length Energy`: 
    LengthEnergy, "LengthEnergy",
    /// `Length Mass`: 
    LengthMass, "LengthMass",
    /// `Length Molar Energy`: 
    LengthMolarEnergy, "LengthMolarEnergy",
    /// `Length per Unit Electric Current`: 
    LengthPerUnitElectricCurrent, "LengthPerUnitElectricCurrent",
    /// `Length Percentage`: 
    LengthPercentage, "LengthPercentage",
    /// `Length Temperature`: 
    LengthTemperature, "LengthTemperature",
    /// `Length Temperature Time`: 
    LengthTemperatureTime, "LengthTemperatureTime",
    /// `Lethargy`: 
    Lethargy, "Lethargy",
    /// `Level Width`: 
    LevelWidth, "LevelWidth",
    /// `Lift Coefficient`: 
    LiftCoefficient, "LiftCoefficient",
    /// `Lift Force`: 
    LiftForce, "LiftForce",
    /// `Linear Absorption Coefficient`: 
    LinearAbsorptionCoefficient, "LinearAbsorptionCoefficient",
    /// `Linear Acceleration`: 
    LinearAcceleration, "LinearAcceleration",
    /// `Linear Attenuation Coefficient`: 
    LinearAttenuationCoefficient, "LinearAttenuationCoefficient",
    /// `Linear Density`: 
    LinearDensity, "LinearDensity",
    /// `Linear Electric Current`: 
    LinearElectricCurrent, "LinearElectricCurrent",
    /// `Linear Electric Current Density`: 
    LinearElectricCurrentDensity, "LinearElectricCurrentDensity",
    /// `Linear Energy Transfer`: 
    LinearEnergyTransfer, "LinearEnergyTransfer",
    /// `Linear Expansion Coefficient`: 
    LinearExpansionCoefficient, "LinearExpansionCoefficient",
    /// `Linear Ionization`: 
    LinearIonization, "LinearIonization",
    /// `Linear Momentum`: 
    LinearMomentum, "LinearMomentum",
    /// `Linear Strain`: 
    LinearStrain, "LinearStrain",
    /// `Linear Thermal Expansion`: 
    LinearThermalExpansion, "LinearThermalExpansion",
    /// `Linear Velocity`: 
    LinearVelocity, "LinearVelocity",
    /// `Linked Flux`: 
    LinkedFlux, "LinkedFlux",
    /// `Liquid Volume`: 
    LiquidVolume, "LiquidVolume",
    /// `Logarithmic frequency interval`: 
    LogarithmicFrequencyInterval, "LogarithmicFrequencyInterval",
    /// `London Penetration Depth`: 
    LondonPenetrationDepth, "LondonPenetrationDepth",
    /// `Long-Range Order Parameter`: 
    Long_RangeOrderParameter, "Long-RangeOrderParameter",
    /// `Lorenz Coefficient`: 
    LorenzCoefficient, "LorenzCoefficient",
    /// `Loss Angle`: 
    LossAngle, "LossAngle",
    /// `Loss Factor`: 
    LossFactor, "LossFactor",
    /// `Lower Critical Magnetic Flux Density`: 
    LowerCriticalMagneticFluxDensity, "LowerCriticalMagneticFluxDensity",
    /// `Luminance`: 
    Luminance, "Luminance",
    /// `Luminous Efficacy`: 
    LuminousEfficacy, "LuminousEfficacy",
    /// `Luminous Emmitance`: 
    LuminousEmmitance, "LuminousEmmitance",
    /// `Luminous Energy`: 
    LuminousEnergy, "LuminousEnergy",
    /// `Luminous Exposure`: 
    LuminousExposure, "LuminousExposure",
    /// `Luminous Flux`: 
    LuminousFlux, "LuminousFlux",
    /// `Luminous Flux per Area`: 
    LuminousFluxPerArea, "LuminousFluxPerArea",
    /// `Luminous Intensity`: 
    LuminousIntensity, "LuminousIntensity",
    /// `Mass Delivered`: 
    MASS_DELIVERED, "MASS-DELIVERED",
    /// `Mass Growth Allowance`: 
    MASS_GROWTH_ALLOWANCE, "MASS-GROWTH-ALLOWANCE",
    /// `Mass Margin`: 
    MASS_MARGIN, "MASS-MARGIN",
    /// `Mass Property Uncertainty`: 
    MASS_PROPERTY_UNCERTAINTY, "MASS-PROPERTY-UNCERTAINTY",
    /// `Moment of Inertia in the Y axis`: 
    MOMENT_OF_INERTIA_Y, "MOMENT-OF-INERTIA_Y",
    /// `Moment of Inertia in the Z axis`: 
    MOMENT_OF_INERTIA_Z, "MOMENT-OF-INERTIA_Z",
    /// `Mach Number`: 
    MachNumber, "MachNumber",
    /// `Macroscopic Cross-section`: 
    MacroscopicCrossSection, "MacroscopicCrossSection",
    /// `Macroscopic Total Cross-section`: 
    MacroscopicTotalCrossSection, "MacroscopicTotalCrossSection",
    /// `Madelung Constant`: 
    MadelungConstant, "MadelungConstant",
    /// `Magnetic Area Moment`: 
    MagneticAreaMoment, "MagneticAreaMoment",
    /// `Magnetic Dipole Moment`: 
    MagneticDipoleMoment, "MagneticDipoleMoment",
    /// `Magnetic Field`: 
    MagneticField, "MagneticField",
    /// `Magnetic Field Strength`: 
    MagneticFieldStrength_H, "MagneticFieldStrength_H",
    /// `Magnetic Flux`: 
    MagneticFlux, "MagneticFlux",
    /// `Magnetic flux density`: 
    MagneticFluxDensity, "MagneticFluxDensity",
    /// `Magnetic flux per unit length`: 
    MagneticFluxPerUnitLength, "MagneticFluxPerUnitLength",
    /// `Magnetic Moment`: 
    MagneticMoment, "MagneticMoment",
    /// `Magnetic Polarization`: 
    MagneticPolarization, "MagneticPolarization",
    /// `Magnetic Quantum Number`: 
    MagneticQuantumNumber, "MagneticQuantumNumber",
    /// `Magnetic Reluctivity`: 
    MagneticReluctivity, "MagneticReluctivity",
    /// `Magnetic Susceptability`: 
    MagneticSusceptability, "MagneticSusceptability",
    /// `Magnetic Tension`: 
    MagneticTension, "MagneticTension",
    /// `Magnetic Vector Potential`: 
    MagneticVectorPotential, "MagneticVectorPotential",
    /// `Magnetization`: 
    Magnetization, "Magnetization",
    /// `Magnetization Field`: 
    MagnetizationField, "MagnetizationField",
    /// `Magnetomotive Force`: 
    MagnetomotiveForce, "MagnetomotiveForce",
    /// `Mass`: 
    Mass, "Mass",
    /// `Mass Absorption Coefficient`: 
    MassAbsorptionCoefficient, "MassAbsorptionCoefficient",
    /// `Mass Amount of Substance`: 
    MassAmountOfSubstance, "MassAmountOfSubstance",
    /// `Mass Amount of Substance Temperature`: 
    MassAmountOfSubstanceTemperature, "MassAmountOfSubstanceTemperature",
    /// `Mass Attenuation Coefficient`: 
    MassAttenuationCoefficient, "MassAttenuationCoefficient",
    /// `Mass Concentration`: 
    MassConcentration, "MassConcentration",
    /// `Mass Concentration of Water`: 
    MassConcentrationOfWater, "MassConcentrationOfWater",
    /// `Mass Concentration of Water Vapour`: 
    MassConcentrationOfWaterVapour, "MassConcentrationOfWaterVapour",
    /// `Mass Defect`: 
    MassDefect, "MassDefect",
    /// `Mass Density`: 
    MassDensity, "MassDensity",
    /// `Mass Energy Transfer Coefficient`: 
    MassEnergyTransferCoefficient, "MassEnergyTransferCoefficient",
    /// `Mass Excess`: 
    MassExcess, "MassExcess",
    /// `Mass Flow Rate`: 
    MassFlowRate, "MassFlowRate",
    /// `Mass Fraction`: 
    MassFraction, "MassFraction",
    /// `Mass Fraction of Dry Matter`: 
    MassFractionOfDryMatter, "MassFractionOfDryMatter",
    /// `Mass Fraction of Water`: 
    MassFractionOfWater, "MassFractionOfWater",
    /// `Mass Number`: 
    MassNumber, "MassNumber",
    /// `Mass Of Electrical Power Supply`: 
    MassOfElectricalPowerSupply, "MassOfElectricalPowerSupply",
    /// `Mass Of Solid Booster`: 
    MassOfSolidBooster, "MassOfSolidBooster",
    /// `Mass Of The Earth`: 
    MassOfTheEarth, "MassOfTheEarth",
    /// `Mass per Area`: 
    MassPerArea, "MassPerArea",
    /// `Mass per Area Time`: 
    MassPerAreaTime, "MassPerAreaTime",
    /// `Mass per Electric Charge`: 
    MassPerElectricCharge, "MassPerElectricCharge",
    /// `Mass per Length`: 
    MassPerLength, "MassPerLength",
    /// `Mass per Time`: 
    MassPerTime, "MassPerTime",
    /// `Mass Ratio`: 
    MassRatio, "MassRatio",
    /// `Mass Concentration of Water To Dry Matter`: 
    MassRatioOfWaterToDryMatter, "MassRatioOfWaterToDryMatter",
    /// `Mass Ratio of Water Vapour to Dry Gas`: 
    MassRatioOfWaterVapourToDryGas, "MassRatioOfWaterVapourToDryGas",
    /// `Mass Temperature`: 
    MassTemperature, "MassTemperature",
    /// `Massic Activity`: 
    MassicActivity, "MassicActivity",
    /// `Massieu Function`: 
    MassieuFunction, "MassieuFunction",
    /// `Maximum Expected Operating Thrust`: 
    MaxExpectedOperatingThrust, "MaxExpectedOperatingThrust",
    /// `Max Operating Thrust`: 
    MaxOperatingThrust, "MaxOperatingThrust",
    /// `Max Sea Level Thrust`: Max Sea Level thrust (Mlbf) 
    MaxSeaLevelThrust, "MaxSeaLevelThrust",
    /// `Maximum Beta-Particle Energy`: 
    MaximumBeta_ParticleEnergy, "MaximumBeta-ParticleEnergy",
    /// `Maximum Expected Operating Pressure`: 
    MaximumExpectedOperatingPressure, "MaximumExpectedOperatingPressure",
    /// `Maximum Operating Pressure`: 
    MaximumOperatingPressure, "MaximumOperatingPressure",
    /// `Mean Energy Imparted`: 
    MeanEnergyImparted, "MeanEnergyImparted",
    /// `Mean Free Path`: 
    MeanFreePath, "MeanFreePath",
    /// `Mean Lifetime`: 
    MeanLifetime, "MeanLifetime",
    /// `Mean Linear Range`: 
    MeanLinearRange, "MeanLinearRange",
    /// `Mean Mass Range`: 
    MeanMassRange, "MeanMassRange",
    /// `Mechanical Energy`: 
    MechanicalEnergy, "MechanicalEnergy",
    /// `Mechanical Impedance`: 
    MechanicalImpedance, "MechanicalImpedance",
    /// `Mechanical Mobility`: 
    MechanicalMobility, "MechanicalMobility",
    /// `Mechanical surface impedance`: 
    MechanicalSurfaceImpedance, "MechanicalSurfaceImpedance",
    /// `Micro Canonical Partition Function`: 
    MicroCanonicalPartitionFunction, "MicroCanonicalPartitionFunction",
    /// `Microbial Formation`: 
    MicrobialFormation, "MicrobialFormation",
    /// `Migration Area`: 
    MigrationArea, "MigrationArea",
    /// `Migration Length`: 
    MigrationLength, "MigrationLength",
    /// `Mobility`: 
    Mobility, "Mobility",
    /// `Mobility Ratio`: 
    MobilityRatio, "MobilityRatio",
    /// `Modulus Of Admittance`: 
    ModulusOfAdmittance, "ModulusOfAdmittance",
    /// `Modulus of Elasticity`: 
    ModulusOfElasticity, "ModulusOfElasticity",
    /// `Modulus Of Impedance`: 
    ModulusOfImpedance, "ModulusOfImpedance",
    /// `Molality of Solute`: 
    MolalityOfSolute, "MolalityOfSolute",
    /// `Molar Absorption Coefficient`: 
    MolarAbsorptionCoefficient, "MolarAbsorptionCoefficient",
    /// `Molar Angular Momentum`: 
    MolarAngularMomentum, "MolarAngularMomentum",
    /// `Molar Attenuation Coefficient`: 
    MolarAttenuationCoefficient, "MolarAttenuationCoefficient",
    /// `Molar Conductivity`: 
    MolarConductivity, "MolarConductivity",
    /// `Molar Energy`: 
    MolarEnergy, "MolarEnergy",
    /// `Molar Entropy`: 
    MolarEntropy, "MolarEntropy",
    /// `Molar Flow Rate`: 
    MolarFlowRate, "MolarFlowRate",
    /// `Molar Heat Capacity`: 
    MolarHeatCapacity, "MolarHeatCapacity",
    /// `Molar Mass`: 
    MolarMass, "MolarMass",
    /// `Molar Optical Rotatory Power`: 
    MolarOpticalRotatoryPower, "MolarOpticalRotatoryPower",
    /// `Molar Volume`: 
    MolarVolume, "MolarVolume",
    /// `Mole Fraction`: 
    MoleFraction, "MoleFraction",
    /// `Molecular Concentration`: 
    MolecularConcentration, "MolecularConcentration",
    /// `Molecular Mass`: 
    MolecularMass, "MolecularMass",
    /// `Molecular Viscosity`: 
    MolecularViscosity, "MolecularViscosity",
    /// `Moment of Force`: 
    MomentOfForce, "MomentOfForce",
    /// `Moment of Inertia`: 
    MomentOfInertia, "MomentOfInertia",
    /// `Momentum`: 
    Momentum, "Momentum",
    /// `Morbidity Rate`: 
    MorbidityRate, "MorbidityRate",
    /// `Mortality Rate`: 
    MortalityRate, "MortalityRate",
    /// `Multiplication Factor`: 
    MultiplicationFactor, "MultiplicationFactor",
    /// `Mutual Inductance`: 
    MutualInductance, "MutualInductance",
    /// `Nominal Ascent Propellant Mass`: 
    NOMINAL_ASCENT_PROPELLANT_MASS, "NOMINAL-ASCENT-PROPELLANT-MASS",
    /// `Napierian Absorbance`: 
    NapierianAbsorbance, "NapierianAbsorbance",
    /// `Neel Temperature`: 
    NeelTemperature, "NeelTemperature",
    /// `Diffusion Coefficient`: 
    NeutronDiffusionCoefficient, "NeutronDiffusionCoefficient",
    /// `Neutron Diffusion Length`: 
    NeutronDiffusionLength, "NeutronDiffusionLength",
    /// `Neutron Number`: 
    NeutronNumber, "NeutronNumber",
    /// `Neutron Yield per Absorption`: 
    NeutronYieldPerAbsorption, "NeutronYieldPerAbsorption",
    /// `Neutron Yield per Fission`: 
    NeutronYieldPerFission, "NeutronYieldPerFission",
    /// `Non-Leakage Probability`: 
    Non_LeakageProbability, "Non-LeakageProbability",
    /// `Non-active Power`: 
    NonActivePower, "NonActivePower",
    /// `Normal Stress`: 
    NormalStress, "NormalStress",
    /// `Nozzle Throat Cross-sectional Area`: 
    NozzleThroatCrossSectionalArea, "NozzleThroatCrossSectionalArea",
    /// `Nozzle Throat Diameter`: 
    NozzleThroatDiameter, "NozzleThroatDiameter",
    /// `Nozzle Throat Pressure`: 
    NozzleThroatPressure, "NozzleThroatPressure",
    /// `Nozzle Walls Thrust Reaction`: 
    NozzleWallsThrustReaction, "NozzleWallsThrustReaction",
    /// `Nuclear Quadrupole Moment`: 
    NuclearQuadrupoleMoment, "NuclearQuadrupoleMoment",
    /// `Nuclear Radius`: 
    NuclearRadius, "NuclearRadius",
    /// `Spin Quantum Number`: 
    NuclearSpinQuantumNumber, "NuclearSpinQuantumNumber",
    /// `Nucleon number`: 
    NucleonNumber, "NucleonNumber",
    /// `Number Density`: 
    NumberDensity, "NumberDensity",
    /// `Number of Particles`: 
    NumberOfParticles, "NumberOfParticles",
    /// `Olfactory Threshold`: 
    OlfactoryThreshold, "OlfactoryThreshold",
    /// `Orbital Angular Momentum per Unit Mass`: 
    OrbitalAngularMomentumPerUnitMass, "OrbitalAngularMomentumPerUnitMass",
    /// `Orbital Angular Momentum Quantum Number`: 
    OrbitalAngularMomentumQuantumNumber, "OrbitalAngularMomentumQuantumNumber",
    /// `Orbital Radial Distance`: 
    OrbitalRadialDistance, "OrbitalRadialDistance",
    /// `Order of Reflection`: 
    OrderOfReflection, "OrderOfReflection",
    /// `Osmotic Coefficient`: 
    OsmoticCoefficient, "OsmoticCoefficient",
    /// `Osmotic Pressure`: 
    OsmoticPressure, "OsmoticPressure",
    /// `Over-range distance`: 
    OverRangeDistance, "OverRangeDistance",
    /// `Predicted Mass`: 
    PREDICTED_MASS, "PREDICTED-MASS",
    /// `Product of Inertia`: 
    PRODUCT_OF_INERTIA, "PRODUCT-OF-INERTIA",
    /// `Product of Inertia in the X axis`: 
    PRODUCT_OF_INERTIA_X, "PRODUCT-OF-INERTIA_X",
    /// `Product of Inertia in the Y axis`: 
    PRODUCT_OF_INERTIA_Y, "PRODUCT-OF-INERTIA_Y",
    /// `Product of Inertia in the Z axis`: 
    PRODUCT_OF_INERTIA_Z, "PRODUCT-OF-INERTIA_Z",
    /// `Packing Fraction`: 
    PackingFraction, "PackingFraction",
    /// `Partial Pressure`: 
    PartialPressure, "PartialPressure",
    /// `Particle Current`: 
    ParticleCurrent, "ParticleCurrent",
    /// `Particle Fluence`: 
    ParticleFluence, "ParticleFluence",
    /// `Particle Fluence Rate`: 
    ParticleFluenceRate, "ParticleFluenceRate",
    /// `Particle Number Density`: 
    ParticleNumberDensity, "ParticleNumberDensity",
    /// `Particle Position Vector`: 
    ParticlePositionVector, "ParticlePositionVector",
    /// `Particle Source Density`: 
    ParticleSourceDensity, "ParticleSourceDensity",
    /// `Path Length`: 
    PathLength, "PathLength",
    /// `Payload Mass`: 
    PayloadMass, "PayloadMass",
    /// `Payload Ratio`: 
    PayloadRatio, "PayloadRatio",
    /// `Peltier Coefficient`: 
    PeltierCoefficient, "PeltierCoefficient",
    /// `Period`: 
    Period, "Period",
    /// `Permeability`: 
    Permeability, "Permeability",
    /// `Permeability Ratio`: 
    PermeabilityRatio, "PermeabilityRatio",
    /// `Permeance`: 
    Permeance, "Permeance",
    /// `Permittivity`: 
    Permittivity, "Permittivity",
    /// `Phase coefficient`: 
    PhaseCoefficient, "PhaseCoefficient",
    /// `Phase Difference`: 
    PhaseDifference, "PhaseDifference",
    /// `Phase speed of sound`: 
    PhaseSpeedOfSound, "PhaseSpeedOfSound",
    /// `Phonon Mean Free Path`: 
    PhononMeanFreePath, "PhononMeanFreePath",
    /// `Photo Threshold of Awareness Function`: 
    PhotoThresholdOfAwarenessFunction, "PhotoThresholdOfAwarenessFunction",
    /// `Photon Intensity`: 
    PhotonIntensity, "PhotonIntensity",
    /// `Photon Radiance`: 
    PhotonRadiance, "PhotonRadiance",
    /// `Photosynthetic Photon Flux`: 
    PhotosyntheticPhotonFlux, "PhotosyntheticPhotonFlux",
    /// `Photosynthetic Photon Flux Density`: 
    PhotosyntheticPhotonFluxDensity, "PhotosyntheticPhotonFluxDensity",
    /// `Planck Function`: 
    PlanckFunction, "PlanckFunction",
    /// `Plane Angle`: 
    PlaneAngle, "PlaneAngle",
    /// `Poisson Ratio`: 
    PoissonRatio, "PoissonRatio",
    /// `Polar moment of inertia`: 
    PolarMomentOfInertia, "PolarMomentOfInertia",
    /// `Polarizability`: 
    Polarizability, "Polarizability",
    /// `Polarization Field`: 
    PolarizationField, "PolarizationField",
    /// `Position Vector`: 
    PositionVector, "PositionVector",
    /// `Potential Energy`: 
    PotentialEnergy, "PotentialEnergy",
    /// `Power`: 
    Power, "Power",
    /// `Power Area`: 
    PowerArea, "PowerArea",
    /// `Power Area per Solid Angle`: 
    PowerAreaPerSolidAngle, "PowerAreaPerSolidAngle",
    /// `Power Factor`: 
    PowerFactor, "PowerFactor",
    /// `Power Per Area`: 
    PowerPerArea, "PowerPerArea",
    /// `Power per Area Angle`: 
    PowerPerAreaAngle, "PowerPerAreaAngle",
    /// `Power per area quartic temperature`: 
    PowerPerAreaQuarticTemperature, "PowerPerAreaQuarticTemperature",
    /// `Power Per Electric Charge`: 
    PowerPerElectricCharge, "PowerPerElectricCharge",
    /// `Poynting Vector`: 
    PoyntingVector, "PoyntingVector",
    /// `Pressure`: 
    Pressure, "Pressure",
    /// `Pressure Burning Rate Constant`: 
    PressureBurningRateConstant, "PressureBurningRateConstant",
    /// `Pressure Burning Rate Index`: 
    PressureBurningRateIndex, "PressureBurningRateIndex",
    /// `Pressure Coefficient`: 
    PressureCoefficient, "PressureCoefficient",
    /// `Pressure Percentage`: 
    PressurePercentage, "PressurePercentage",
    /// `Pressure Ratio`: 
    PressureRatio, "PressureRatio",
    /// `Prevalence`: 
    Prevalence, "Prevalence",
    /// `Principal Quantum Number`: 
    PrincipalQuantumNumber, "PrincipalQuantumNumber",
    /// `Propagation coefficient`: 
    PropagationCoefficient, "PropagationCoefficient",
    /// `Propellant Burn Rate`: 
    PropellantBurnRate, "PropellantBurnRate",
    /// `Propellant Mass`: 
    PropellantMass, "PropellantMass",
    /// `Propellant Mean Bulk Temperature`: 
    PropellantMeanBulkTemperature, "PropellantMeanBulkTemperature",
    /// `Propellant Temperature`: 
    PropellantTemperature, "PropellantTemperature",
    /// `Quality Factor`: 
    QualityFactor, "QualityFactor",
    /// `Quantum Number`: 
    QuantumNumber, "QuantumNumber",
    /// `Quartic Electric Dipole Moment per Cubic Energy`: 
    QuarticElectricDipoleMomentPerCubicEnergy, "QuarticElectricDipoleMomentPerCubicEnergy",
    /// `Reserve Mass`: 
    RESERVE_MASS, "RESERVE-MASS",
    /// `RF-Power Level`: 
    RF_Power, "RF-Power",
    /// `Radial Distance`: 
    RadialDistance, "RadialDistance",
    /// `Radiance`: 
    Radiance, "Radiance",
    /// `Radiance Factor`: 
    RadianceFactor, "RadianceFactor",
    /// `Radiant Emmitance`: 
    RadiantEmmitance, "RadiantEmmitance",
    /// `Radiant Energy`: 
    RadiantEnergy, "RadiantEnergy",
    /// `Radiant Energy Density`: 
    RadiantEnergyDensity, "RadiantEnergyDensity",
    /// `Radiant Exposure`: 
    RadiantExposure, "RadiantExposure",
    /// `Radiant Fluence`: 
    RadiantFluence, "RadiantFluence",
    /// `Radiant Fluence Rate`: 
    RadiantFluenceRate, "RadiantFluenceRate",
    /// `Radiant Flux`: 
    RadiantFlux, "RadiantFlux",
    /// `Radiant Intensity`: 
    RadiantIntensity, "RadiantIntensity",
    /// `Radiative Heat Transfer`: 
    RadiativeHeatTransfer, "RadiativeHeatTransfer",
    /// `Radiosity`: 
    Radiosity, "Radiosity",
    /// `Radius`: 
    Radius, "Radius",
    /// `Radius of Curvature`: 
    RadiusOfCurvature, "RadiusOfCurvature",
    /// `Ratio of Specific Heat Capacities`: 
    RatioOfSpecificHeatCapacities, "RatioOfSpecificHeatCapacities",
    /// `Reactance`: 
    Reactance, "Reactance",
    /// `Reaction Energy`: 
    ReactionEnergy, "ReactionEnergy",
    /// `Reactive Power`: 
    ReactivePower, "ReactivePower",
    /// `Reactivity`: 
    Reactivity, "Reactivity",
    /// `Reactor Time Constant`: 
    ReactorTimeConstant, "ReactorTimeConstant",
    /// `Recombination Coefficient`: 
    RecombinationCoefficient, "RecombinationCoefficient",
    /// `Refectance`: 
    Refectance, "Refectance",
    /// `Reflectance`: 
    Reflectance, "Reflectance",
    /// `Reflectance Factor`: 
    ReflectanceFactor, "ReflectanceFactor",
    /// `Refractive index`: 
    RefractiveIndex, "RefractiveIndex",
    /// `Relative Atomic Mass`: 
    RelativeAtomicMass, "RelativeAtomicMass",
    /// `Relative Humidity`: 
    RelativeHumidity, "RelativeHumidity",
    /// `Relative Mass Concentration of Vapour`: 
    RelativeMassConcentrationOfVapour, "RelativeMassConcentrationOfVapour",
    /// `Relative Mass Defect`: 
    RelativeMassDefect, "RelativeMassDefect",
    /// `Relative Mass Density`: 
    RelativeMassDensity, "RelativeMassDensity",
    /// `Relative Mass Excess`: 
    RelativeMassExcess, "RelativeMassExcess",
    /// `Relative Mass Ratio of Vapour`: 
    RelativeMassRatioOfVapour, "RelativeMassRatioOfVapour",
    /// `Relative Molecular Mass`: 
    RelativeMolecularMass, "RelativeMolecularMass",
    /// `Relative Partial Pressure`: 
    RelativePartialPressure, "RelativePartialPressure",
    /// `Relative Permittivity`: 
    RelativePermittivity, "RelativePermittivity",
    /// `Relative Pressure Coefficient`: 
    RelativePressureCoefficient, "RelativePressureCoefficient",
    /// `Relaxation TIme`: 
    RelaxationTIme, "RelaxationTIme",
    /// `Reluctance`: 
    Reluctance, "Reluctance",
    /// `Residual Resistivity`: 
    ResidualResistivity, "ResidualResistivity",
    /// `Resistance`: 
    Resistance, "Resistance",
    /// `Resistance Percentage`: 
    ResistancePercentage, "ResistancePercentage",
    /// `Resistivity`: 
    Resistivity, "Resistivity",
    /// `Resonance Energy`: 
    ResonanceEnergy, "ResonanceEnergy",
    /// `Resonance Escape Probability`: 
    ResonanceEscapeProbability, "ResonanceEscapeProbability",
    /// `Resonance Escape Probability For Fission`: 
    ResonanceEscapeProbabilityForFission, "ResonanceEscapeProbabilityForFission",
    /// `Respiratory Rate`: 
    RespiratoryRate, "RespiratoryRate",
    /// `Rest Energy`: 
    RestEnergy, "RestEnergy",
    /// `Rest Mass`: 
    RestMass, "RestMass",
    /// `Reverberation Time`: 
    ReverberationTime, "ReverberationTime",
    /// `Reynolds Number`: 
    ReynoldsNumber, "ReynoldsNumber",
    /// `Richardson Constant`: 
    RichardsonConstant, "RichardsonConstant",
    /// `Rocket Atmospheric Transverse Force`: 
    RocketAtmosphericTransverseForce, "RocketAtmosphericTransverseForce",
    /// `Scalar Magnetic Potential`: 
    ScalarMagneticPotential, "ScalarMagneticPotential",
    /// `Second Axial Moment of Area`: 
    SecondAxialMomentOfArea, "SecondAxialMomentOfArea",
    /// `Second Moment of Area`: 
    SecondMomentOfArea, "SecondMomentOfArea",
    /// `Second Polar Moment of Area`: 
    SecondPolarMomentOfArea, "SecondPolarMomentOfArea",
    /// `Second Stage Mass Ratio`: 
    SecondStageMassRatio, "SecondStageMassRatio",
    /// `Section Modulus`: 
    SectionModulus, "SectionModulus",
    /// `Seebeck Coefficient`: 
    SeebeckCoefficient, "SeebeckCoefficient",
    /// `Serum or Plasma Level`: 
    SerumOrPlasmaLevel, "SerumOrPlasmaLevel",
    /// `Shear Modulus`: 
    ShearModulus, "ShearModulus",
    /// `Shear Strain`: 
    ShearStrain, "ShearStrain",
    /// `Shear Stress`: 
    ShearStress, "ShearStress",
    /// `Short-Range Order Parameter`: 
    Short_RangeOrderParameter, "Short-RangeOrderParameter",
    /// `Signal Detection Threshold`: 
    SignalDetectionThreshold, "SignalDetectionThreshold",
    /// `Signal Strength`: 
    SignalStrength, "SignalStrength",
    /// `Single Stage Launcher Mass Ratio`: 
    SingleStageLauncherMassRatio, "SingleStageLauncherMassRatio",
    /// `Slowing-Down Area`: 
    Slowing_DownArea, "Slowing-DownArea",
    /// `Slowing-Down Density`: 
    Slowing_DownDensity, "Slowing-DownDensity",
    /// `Slowing-Down Length`: 
    Slowing_DownLength, "Slowing-DownLength",
    /// `Solid Angle`: 
    SolidAngle, "SolidAngle",
    /// `Diffusion Length (Solid State Physics)`: 
    SolidStateDiffusionLength, "SolidStateDiffusionLength",
    /// `Sound energy density`: 
    SoundEnergyDensity, "SoundEnergyDensity",
    /// `Sound exposure`: 
    SoundExposure, "SoundExposure",
    /// `Sound exposure level`: 
    SoundExposureLevel, "SoundExposureLevel",
    /// `Sound intensity`: 
    SoundIntensity, "SoundIntensity",
    /// `Sound particle acceleration`: 
    SoundParticleAcceleration, "SoundParticleAcceleration",
    /// `Sound Particle Displacement`: 
    SoundParticleDisplacement, "SoundParticleDisplacement",
    /// `Sound particle velocity`: 
    SoundParticleVelocity, "SoundParticleVelocity",
    /// `Sound power`: 
    SoundPower, "SoundPower",
    /// `Sound power level`: 
    SoundPowerLevel, "SoundPowerLevel",
    /// `Sound pressure`: 
    SoundPressure, "SoundPressure",
    /// `Sound pressure level`: 
    SoundPressureLevel, "SoundPressureLevel",
    /// `Sound reduction index`: 
    SoundReductionIndex, "SoundReductionIndex",
    /// `Sound volume velocity`: 
    SoundVolumeVelocity, "SoundVolumeVelocity",
    /// `Source Voltage`: 
    SourceVoltage, "SourceVoltage",
    /// `Source Voltage Between Substances`: 
    SourceVoltageBetweenSubstances, "SourceVoltageBetweenSubstances",
    /// `Spatial Summation Function`: 
    SpatialSummationFunction, "SpatialSummationFunction",
    /// `Specific Acoustic Impedance`: 
    SpecificAcousticImpedance, "SpecificAcousticImpedance",
    /// `Specific Activity`: 
    SpecificActivity, "SpecificActivity",
    /// `Specific Energy`: 
    SpecificEnergy, "SpecificEnergy",
    /// `Specific Energy Imparted`: 
    SpecificEnergyImparted, "SpecificEnergyImparted",
    /// `Specific Enthalpy`: 
    SpecificEnthalpy, "SpecificEnthalpy",
    /// `Specific Entropy`: 
    SpecificEntropy, "SpecificEntropy",
    /// `Specific Gibbs Energy`: 
    SpecificGibbsEnergy, "SpecificGibbsEnergy",
    /// `Specific Heat Capacity`: 
    SpecificHeatCapacity, "SpecificHeatCapacity",
    /// `Specific heat capacity at constant pressure`: 
    SpecificHeatCapacityAtConstantPressure, "SpecificHeatCapacityAtConstantPressure",
    /// `Specific heat capacity at constant volume`: 
    SpecificHeatCapacityAtConstantVolume, "SpecificHeatCapacityAtConstantVolume",
    /// `Specific Heat Capacity at Saturation`: 
    SpecificHeatCapacityAtSaturation, "SpecificHeatCapacityAtSaturation",
    /// `Specific Heat Pressure`: 
    SpecificHeatPressure, "SpecificHeatPressure",
    /// `Specific Heat Volume`: 
    SpecificHeatVolume, "SpecificHeatVolume",
    /// `Specific Heats Ratio`: 
    SpecificHeatsRatio, "SpecificHeatsRatio",
    /// `Specific Helmholtz Energy`: 
    SpecificHelmholtzEnergy, "SpecificHelmholtzEnergy",
    /// `Specific Impulse`: 
    SpecificImpulse, "SpecificImpulse",
    /// `Specific Impulse by Mass`: 
    SpecificImpulseByMass, "SpecificImpulseByMass",
    /// `Specific Impulse by Weight`: 
    SpecificImpulseByWeight, "SpecificImpulseByWeight",
    /// `Specific Internal Energy`: 
    SpecificInternalEnergy, "SpecificInternalEnergy",
    /// `Specific Optical Rotatory Power`: 
    SpecificOpticalRotatoryPower, "SpecificOpticalRotatoryPower",
    /// `Specific thrust`: 
    SpecificThrust, "SpecificThrust",
    /// `Specific Volume`: 
    SpecificVolume, "SpecificVolume",
    /// `Spectral Angular Cross-section`: 
    SpectralAngularCrossSection, "SpectralAngularCrossSection",
    /// `Spectral Cross-section`: 
    SpectralCrossSection, "SpectralCrossSection",
    /// `Spectral Luminous Efficiency`: 
    SpectralLuminousEfficiency, "SpectralLuminousEfficiency",
    /// `Spectral Radiant Energy Density`: 
    SpectralRadiantEnergyDensity, "SpectralRadiantEnergyDensity",
    /// `Speed`: 
    Speed, "Speed",
    /// `Speed of Light`: 
    SpeedOfLight, "SpeedOfLight",
    /// `Speed of sound`: 
    SpeedOfSound, "SpeedOfSound",
    /// `Illuminance`: 
    SphericalIlluminance, "SphericalIlluminance",
    /// `Spin`: 
    Spin, "Spin",
    /// `Spin Quantum Number`: 
    SpinQuantumNumber, "SpinQuantumNumber",
    /// `Square Energy`: 
    SquareEnergy, "SquareEnergy",
    /// `Stage Propellant Mass`: 
    StagePropellantMass, "StagePropellantMass",
    /// `Stage Structure Mass`: 
    StageStructuralMass, "StageStructuralMass",
    /// `Standard Absolute Activity`: 
    StandardAbsoluteActivity, "StandardAbsoluteActivity",
    /// `Standard Chemical Potential`: 
    StandardChemicalPotential, "StandardChemicalPotential",
    /// `Standard Gravitational Parameter`: 
    StandardGravitationalParameter, "StandardGravitationalParameter",
    /// `Static Friction`: 
    StaticFriction, "StaticFriction",
    /// `Static Friction Coefficient`: 
    StaticFrictionCoefficient, "StaticFrictionCoefficient",
    /// `Static pressure`: 
    StaticPressure, "StaticPressure",
    /// `Statistical Weight`: 
    StatisticalWeight, "StatisticalWeight",
    /// `Stochastic Process`: 
    StochasticProcess, "StochasticProcess",
    /// `Stoichiometric Number`: 
    StoichiometricNumber, "StoichiometricNumber",
    /// `Strain`: 
    Strain, "Strain",
    /// `Strain Energy Density`: 
    StrainEnergyDensity, "StrainEnergyDensity",
    /// `Stress`: 
    Stress, "Stress",
    /// `Structural Efficiency`: 
    StructuralEfficiency, "StructuralEfficiency",
    /// `Structure Factor`: 
    StructureFactor, "StructureFactor",
    /// `Superconduction Transition Temperature`: 
    SuperconductionTransitionTemperature, "SuperconductionTransitionTemperature",
    /// `Superconductor Energy Gap`: 
    SuperconductorEnergyGap, "SuperconductorEnergyGap",
    /// `Surface Activity Density`: 
    SurfaceActivityDensity, "SurfaceActivityDensity",
    /// `Surface Coefficient of Heat Transfer`: 
    SurfaceCoefficientOfHeatTransfer, "SurfaceCoefficientOfHeatTransfer",
    /// `Surface Density`: 
    SurfaceDensity, "SurfaceDensity",
    /// `Surface Tension`: 
    SurfaceTension, "SurfaceTension",
    /// `Susceptance`: 
    Susceptance, "Susceptance",
    /// `Systolic Blood Pressure`: 
    SystolicBloodPressure, "SystolicBloodPressure",
    /// `Target Bogie Mass`: 
    TARGET_BOGIE_MASS, "TARGET-BOGIE-MASS",
    /// `Temperature`: 
    Temperature, "Temperature",
    /// `Temperature Amount of Substance`: 
    TemperatureAmountOfSubstance, "TemperatureAmountOfSubstance",
    /// `Temperature per Magnetic Flux Density`: 
    TemperaturePerMagneticFluxDensity, "TemperaturePerMagneticFluxDensity",
    /// `Temperature per Time`: 
    TemperaturePerTime, "TemperaturePerTime",
    /// `Temperature Ratio`: 
    TemperatureRatio, "TemperatureRatio",
    /// `Temporal Summation Function`: 
    TemporalSummationFunction, "TemporalSummationFunction",
    /// `Tension`: 
    Tension, "Tension",
    /// `Thermal Conductance`: 
    ThermalConductance, "ThermalConductance",
    /// `Thermal Conductivity`: 
    ThermalConductivity, "ThermalConductivity",
    /// `Thermal Diffusion Factor`: 
    ThermalDiffusionFactor, "ThermalDiffusionFactor",
    /// `Thermal Diffusion Ratio`: 
    ThermalDiffusionRatio, "ThermalDiffusionRatio",
    /// `Thermal Diffusion Coefficient`: 
    ThermalDiffusionRatioCoefficient, "ThermalDiffusionRatioCoefficient",
    /// `Thermal Diffusivity`: 
    ThermalDiffusivity, "ThermalDiffusivity",
    /// `Thermal Efficiency`: 
    ThermalEfficiency, "ThermalEfficiency",
    /// `Thermal Energy`: 
    ThermalEnergy, "ThermalEnergy",
    /// `Thermal Energy Length`: 
    ThermalEnergyLength, "ThermalEnergyLength",
    /// `Thermal Insulance`: 
    ThermalInsulance, "ThermalInsulance",
    /// `Thermal Resistance`: 
    ThermalResistance, "ThermalResistance",
    /// `Thermal Resistivity`: 
    ThermalResistivity, "ThermalResistivity",
    /// `Thermal Utilization Factor`: 
    ThermalUtilizationFactor, "ThermalUtilizationFactor",
    /// `Thermal Utilization Factor For Fission`: 
    ThermalUtilizationFactorForFission, "ThermalUtilizationFactorForFission",
    /// `Thermodynamic Critical Magnetic Flux Density`: 
    ThermodynamicCriticalMagneticFluxDensity, "ThermodynamicCriticalMagneticFluxDensity",
    /// `Thermodynamic Energy`: 
    ThermodynamicEnergy, "ThermodynamicEnergy",
    /// `Thermodynamic Entropy`: 
    ThermodynamicEntropy, "ThermodynamicEntropy",
    /// `Thermodynamic Temperature`: 
    ThermodynamicTemperature, "ThermodynamicTemperature",
    /// `Thickness`: 
    Thickness, "Thickness",
    /// `Thomson Coefficient`: 
    ThomsonCoefficient, "ThomsonCoefficient",
    /// `Thrust`: 
    Thrust, "Thrust",
    /// `Thrust Coefficient`: 
    ThrustCoefficient, "ThrustCoefficient",
    /// `Thrust To Mass Ratio`: 
    ThrustToMassRatio, "ThrustToMassRatio",
    /// `Thrust To Weight Ratio`: 
    ThrustToWeightRatio, "ThrustToWeightRatio",
    /// `Thruster Power To Thrust Efficiency`: 
    ThrusterPowerToThrustEfficiency, "ThrusterPowerToThrustEfficiency",
    /// `Time`: 
    Time, "Time",
    /// `Time averaged sound intensity`: 
    TimeAveragedSoundIntensity, "TimeAveragedSoundIntensity",
    /// `Time Percentage`: 
    TimePercentage, "TimePercentage",
    /// `Time Squared`: 
    TimeSquared, "TimeSquared",
    /// `Time Temperature`: 
    TimeTemperature, "TimeTemperature",
    /// `Torque`: 
    Torque, "Torque",
    /// `Total Angular Momentum`: 
    TotalAngularMomentum, "TotalAngularMomentum",
    /// `Total Angular Momentum Quantum Number`: 
    TotalAngularMomentumQuantumNumber, "TotalAngularMomentumQuantumNumber",
    /// `Total Atomic Stopping Power`: 
    TotalAtomicStoppingPower, "TotalAtomicStoppingPower",
    /// `Total Cross-section`: 
    TotalCrossSection, "TotalCrossSection",
    /// `Total Current`: 
    TotalCurrent, "TotalCurrent",
    /// `Total Current Density`: 
    TotalCurrentDensity, "TotalCurrentDensity",
    /// `Total Ionization`: 
    TotalIonization, "TotalIonization",
    /// `Total Linear Stopping Power`: 
    TotalLinearStoppingPower, "TotalLinearStoppingPower",
    /// `Total Mass Stopping Power`: 
    TotalMassStoppingPower, "TotalMassStoppingPower",
    /// `Total Pressure`: 
    TotalPressure, "TotalPressure",
    /// `Touch Thresholds`: 
    TouchThresholds, "TouchThresholds",
    /// `Transmittance`: 
    Transmittance, "Transmittance",
    /// `Transmittance Density`: 
    TransmittanceDensity, "TransmittanceDensity",
    /// `True Exhaust Velocity`: 
    TrueExhaustVelocity, "TrueExhaustVelocity",
    /// `Turbidity`: 
    Turbidity, "Turbidity",
    /// `Turns`: 
    Turns, "Turns",
    /// `Universal Gas Constant`: 
    UniversalGasConstant, "UniversalGasConstant",
    /// `Upper Critical Magnetic Flux Density`: 
    UpperCriticalMagneticFluxDensity, "UpperCriticalMagneticFluxDensity",
    /// `Vacuum Thrust`: 
    VacuumThrust, "VacuumThrust",
    /// `Vehicle Velocity`: 
    VehicleVelocity, "VehicleVelocity",
    /// `Velocity`: 
    Velocity, "Velocity",
    /// `Vertical Velocity`: 
    VerticalVelocity, "VerticalVelocity",
    /// `Video Frame Rate`: 
    VideoFrameRate, "VideoFrameRate",
    /// `Viscosity`: 
    Viscosity, "Viscosity",
    /// `Visible Radiant Energy`: 
    VisibleRadiantEnergy, "VisibleRadiantEnergy",
    /// `Vision Threshods`: 
    VisionThreshods, "VisionThreshods",
    /// `Voltage`: 
    Voltage, "Voltage",
    /// `Voltage Percentage`: 
    VoltagePercentage, "VoltagePercentage",
    /// `Voltage Phasor`: 
    VoltagePhasor, "VoltagePhasor",
    /// `Volume`: 
    Volume, "Volume",
    /// `Volume Flow Rate`: 
    VolumeFlowRate, "VolumeFlowRate",
    /// `Volume Fraction`: 
    VolumeFraction, "VolumeFraction",
    /// `Volume per Unit Time`: 
    VolumePerUnitTime, "VolumePerUnitTime",
    /// `Volume Strain`: 
    VolumeStrain, "VolumeStrain",
    /// `Volume Thermal Expansion`: 
    VolumeThermalExpansion, "VolumeThermalExpansion",
    /// `Volumetric Flux`: 
    VolumetricFlux, "VolumetricFlux",
    /// `Volumetric Heat Capacity`: 
    VolumetricHeatCapacity, "VolumetricHeatCapacity",
    /// `Volumic Electromagnetic Energy`: 
    VolumicElectromagneticEnergy, "VolumicElectromagneticEnergy",
    /// `Vorticity`: 
    Vorticity, "Vorticity",
    /// `Warm Receptor Threshold`: 
    WarmReceptorThreshold, "WarmReceptorThreshold",
    /// `Water Horsepower`: 
    WaterHorsepower, "WaterHorsepower",
    /// `Wavelength`: 
    Wavelength, "Wavelength",
    /// `Wavenumber`: 
    Wavenumber, "Wavenumber",
    /// `Web Time`: Web Time
    WebTime, "WebTime",
    /// `Web Time Average Pressure`: 
    WebTimeAveragePressure, "WebTimeAveragePressure",
    /// `Web Time Average Thrust`: Web Time Avg Thrust (Mlbf)
    WebTimeAverageThrust, "WebTimeAverageThrust",
    /// `Weight`: 
    Weight, "Weight",
    /// `Width`: 
    Width, "Width",
    /// `Work`: 
    Work, "Work",
    /// `Work Function`: 
    WorkFunction, "WorkFunction"
);
